@@ -260,8 +260,10 @@ QByteArray QOAuth::InterfacePrivate::httpMethodToString( HttpMethod method )
         return "HEAD";
     case PUT:
         return "PUT";
+#ifndef Q_WS_WIN
     case DELETE:
         return "DELETE";
+#endif
     default:
         qWarning() << __FUNCTION__ << "- Unrecognized method";
         return QByteArray();
@@ -937,7 +939,7 @@ QOAuth::ParamMap QOAuth::InterfacePrivate::sendRequest( const QString &requestUr
         // create the authorization header
         request.setRawHeader( "Authorization", authorizationHeader );
     } else if ( httpMethod == POST ) {
-        authorizationHeader = paramsToString( parameters, ParseForInlineQuery );
+        authorizationHeader = paramsToString( parameters, ParseForRequestContent );
         // create a network request
         request.setHeader( QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded" );
     }
